==> connectors-internal-api-3.0-b58-sources.jar: org/glassfish/resources/custom/factory/PrimitivesAndStringFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.resources.custom.factory;


import javax.naming.spi.ObjectFactory;
import javax.naming.Name;
import javax.naming.Context;
import javax.naming.Reference;
import javax.naming.RefAddr;
import java.io.Serializable;
import java.util.Hashtable;
import java.util.Enumeration;

public class PrimitivesAndStringFactory implements Serializable, ObjectFactory {

    public Object getObjectInstance(Object obj, Name name, Context nameCtx, Hashtable<?, ?> environment) throws Exception {
        Reference ref = (Reference)obj;

        Enumeration<RefAddr> refAddrs = ref.getAll();
        String type = null;
        String value = null;
        while(refAddrs.hasMoreElements()){
            RefAddr addr = refAddrs.nextElement();
            String propName = addr.getType();

            type = ref.getClassName();

            if(propName.equalsIgnoreCase("value")){
                value = (String)addr.getContent();
            }
        }

        if(type != null && value != null){
            type = type.toUpperCase();
            if(type.endsWith("INT") || type.endsWith("INTEGER")){
                return Integer.valueOf(value);
            } else if (type.endsWith("LONG")){
                return Long.valueOf(value);
            } else if(type.endsWith("DOUBLE")){
                return Double.valueOf(value);
            } else if(type.endsWith("FLOAT") ){
                return Float.valueOf(value);
            } else if(type.endsWith("CHAR") || type.endsWith("CHARACTER")){
                return value.charAt(0);
            } else if(type.endsWith("SHORT")){
                return Short.valueOf(value);
            } else if(type.endsWith("BYTE")){
                return Byte.valueOf(value);
            } else if(type.endsWith("BOOLEAN")){
                return Boolean.valueOf(value);
            } else if(type.endsWith("STRING")){
                return value;
            }
        }
        //TODO V3 log
        return null;
    }
}

==> connectors-internal-api-3.1-b06-sources.jar: org/glassfish/resources/custom/factory/PrimitivesAndStringFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.resources.custom.factory;


import javax.naming.spi.ObjectFactory;
import javax.naming.Name;
import javax.naming.Context;
import javax.naming.Reference;
import javax.naming.RefAddr;
import java.io.Serializable;
import java.util.Hashtable;
import java.util.Enumeration;

public class PrimitivesAndStringFactory implements Serializable, ObjectFactory {

    public Object getObjectInstance(Object obj, Name name, Context nameCtx, Hashtable<?, ?> environment) throws Exception {
        Reference ref = (Reference)obj;

        Enumeration<RefAddr> refAddrs = ref.getAll();
        String type = null;
        String value = null;
        while(refAddrs.hasMoreElements()){
            RefAddr addr = refAddrs.nextElement();
            String propName = addr.getType();

            type = ref.getClassName();

            if(propName.equalsIgnoreCase("value")){
                value = (String)addr.getContent();
            }
        }

        if(type != null && value != null){
            type = type.toUpperCase();
            if(type.endsWith("INT") || type.endsWith("INTEGER")){
                return Integer.valueOf(value);
            } else if (type.endsWith("LONG")){
                return Long.valueOf(value);
            } else if(type.endsWith("DOUBLE")){
                return Double.valueOf(value);
            } else if(type.endsWith("FLOAT") ){
                return Float.valueOf(value);
            } else if(type.endsWith("CHAR") || type.endsWith("CHARACTER")){
                return value.charAt(0);
            } else if(type.endsWith("SHORT")){
                return Short.valueOf(value);
            } else if(type.endsWith("BYTE")){
                return Byte.valueOf(value);
            } else if(type.endsWith("BOOLEAN")){
                return Boolean.valueOf(value);
            } else if(type.endsWith("STRING")){
                return value;
            }else{
                throw new IllegalArgumentException("unknown type ["+type+"] ");
            }
        }else if (type == null){
            throw new IllegalArgumentException("type cannot be null");
        }else{
            throw new IllegalAccessException("value cannot be null");
        }
    }
}
